@@ -10,14 +10,20 @@ import ujson
 
 
 def import_path(dotted_path: str):
-    module_path, object_name = dotted_path.rsplit('.', maxsplit=1)
+    if ':' in dotted_path:
+        module_path, attr_path = dotted_path.rsplit(':', maxsplit=1)
+    else:
+        module_path, attr_path = dotted_path.rsplit('.', maxsplit=1)
+
     module = import_module(module_path)
 
-    if ':' in object_name:
-        object_name, attr_name = object_name.rsplit(':', maxsplit=1)
-        return getattr(getattr(module, object_name), attr_name)
+    if ':' in dotted_path:
+        result = module
+        for attr_name in attr_path.rsplit('.'):
+            result = getattr(result, attr_name)
+        return result
 
-    return getattr(module, object_name)
+    return getattr(module, attr_path)
 
 
 def lazy_import(dotted_path: str, callable: bool = False, as_partial: bool = False):
@@ -57,7 +63,9 @@ async def invoke_async(func, *args, **kwargs):
     if iscoroutinefunction_partial(func):
         return await func(*args, **kwargs)
     else:
-        return func(*args, **kwargs)
+        loop = get_running_loop()
+        func = partial(func, *args, **kwargs)
+        return await loop.run_in_executor(None, func)
 
 
 def snake2kebab(string: str) -> str:
