@@ -2,32 +2,33 @@ import asyncio
 
 import pytest
 
-from dropland.blocks.redis import USE_REDIS
-from dropland.blocks.rmq import USE_RMQ
-from dropland.blocks.sql import USE_SQL
-from dropland.blocks.sql.base import SqlStorageType
+from dropland.engines.redis import USE_REDIS
+from dropland.engines.rmq import USE_RMQ
+from dropland.engines.sql import USE_SQL
+from dropland.engines.sql.base import SqlEngineType
 
 if USE_REDIS:
-    from dropland.blocks.redis.containers import default_redis_storage
-    from dropland.blocks.redis.engine import EngineConfig as RedisEngineConfig
+    from dropland.engines.redis.containers import RedisBlock
+    from dropland.engines.redis.engine import EngineConfig as RedisEngineConfig
+    from .redis_models_data import redis_container
 
 if USE_RMQ:
-    from dropland.blocks.rmq.containers import default_rmq_storage
-    from dropland.blocks.rmq.engine import EngineConfig as RmqEngineConfig
+    from dropland.engines.rmq.containers import RmqContainer, RmqBlock
+    from dropland.engines.rmq.engine import EngineConfig as RmqEngineConfig
 
 if USE_SQL:
-    from dropland.blocks.sql.containers import MultipleSqlStorage, default_sql_storage
-    from dropland.blocks.sql import EngineConfig as SqlEngineConfig
+    from dropland.engines.sql.containers import MultipleSqlContainer, SqlContainer, SqlBlock
+    from dropland.engines.sql import EngineConfig as SqlEngineConfig
 
 from tests import MYSQL_URI, POSTGRES_URI, REDIS_URI, RMQ_URI, SQLITE_URI
 
 
 if USE_SQL:
-    sql_storage = MultipleSqlStorage()
+    sql_storage = MultipleSqlContainer()
 
     sql_storage.config.from_dict({
         'sqlite': {
-            'db_type': SqlStorageType.SQLITE,
+            'db_type': SqlEngineType.SQLITE,
             'engine_config': SqlEngineConfig(
                 url=SQLITE_URI,
                 pool_min_size=1, pool_max_size=2,
@@ -36,7 +37,7 @@ if USE_SQL:
             'use_async': False
         },
         'asqlite': {
-            'db_type': SqlStorageType.SQLITE,
+            'db_type': SqlEngineType.SQLITE,
             'engine_config': SqlEngineConfig(
                 url=SQLITE_URI,
                 pool_min_size=1, pool_max_size=2,
@@ -45,7 +46,7 @@ if USE_SQL:
             'use_async': True
         },
         'pg': {
-            'db_type': SqlStorageType.POSTGRES,
+            'db_type': SqlEngineType.POSTGRES,
             'engine_config': SqlEngineConfig(
                 url=POSTGRES_URI,
                 pool_min_size=1, pool_max_size=2,
@@ -54,7 +55,7 @@ if USE_SQL:
             'use_async': False
         },
         'apg': {
-            'db_type': SqlStorageType.POSTGRES,
+            'db_type': SqlEngineType.POSTGRES,
             'engine_config': SqlEngineConfig(
                 url=POSTGRES_URI,
                 pool_min_size=1, pool_max_size=2,
@@ -63,7 +64,7 @@ if USE_SQL:
             'use_async': True
         },
         'ms': {
-            'db_type': SqlStorageType.MYSQL,
+            'db_type': SqlEngineType.MYSQL,
             'engine_config': SqlEngineConfig(
                 url=MYSQL_URI,
                 pool_min_size=1, pool_max_size=2,
@@ -72,7 +73,7 @@ if USE_SQL:
             'use_async': False
         },
         'ams': {
-            'db_type': SqlStorageType.MYSQL,
+            'db_type': SqlEngineType.MYSQL,
             'engine_config': SqlEngineConfig(
                 url=MYSQL_URI,
                 pool_min_size=1, pool_max_size=2,
@@ -86,7 +87,7 @@ if USE_SQL:
 @pytest.fixture(scope='session')
 def test_sql_storage():
     if USE_SQL:
-        return default_sql_storage
+        return SqlContainer()
     else:
         return None
 
@@ -94,7 +95,7 @@ def test_sql_storage():
 @pytest.fixture(scope='session')
 def test_redis_storage():
     if USE_REDIS:
-        return default_redis_storage
+        return redis_container
     else:
         return None
 
@@ -102,23 +103,23 @@ def test_redis_storage():
 @pytest.fixture(scope='session')
 def test_rmq_storage():
     if USE_RMQ:
-        return default_rmq_storage
+        return RmqContainer()
     else:
         return None
 
 
 @pytest.fixture(scope='session')
-def sql_sync_engine():
+def sql_sync_engine(test_sql_storage):
     conf = sql_storage.config.get('sqlite')
-    return default_sql_storage.create_engine(
+    return test_sql_storage.create_engine(
         'dropland-test-sync', conf['engine_config'], conf['db_type'], conf.get('use_async')
     )
 
 
 @pytest.fixture(scope='session')
-def sql_async_engine():
+def sql_async_engine(test_sql_storage):
     conf = sql_storage.config.get('asqlite')
-    return default_sql_storage.create_engine(
+    return test_sql_storage.create_engine(
         'dropland-test-async', conf['engine_config'], conf['db_type'], conf.get('use_async')
     )
 
@@ -154,15 +155,15 @@ def mysql_async_engine():
 
 
 @pytest.fixture(scope='session')
-def redis_engine():
+def redis_engine(test_redis_storage):
     engine_config = RedisEngineConfig(url=REDIS_URI)
-    return default_redis_storage.create_engine('dropland', engine_config)
+    return test_redis_storage.create_engine('dropland', engine_config)
 
 
 @pytest.fixture(scope='session')
-def rmq_engine():
+def rmq_engine(test_rmq_storage):
     engine_config = RmqEngineConfig(url=RMQ_URI)
-    return default_rmq_storage.create_engine('dropland', engine_config)
+    return test_rmq_storage.create_engine('dropland', engine_config)
 
 
 @pytest.fixture(scope='session')
@@ -174,41 +175,53 @@ def event_loop():
 
 if USE_SQL:
     @pytest.fixture(scope='function')
-    def sync_sql_session(event_loop):
-        session = default_sql_storage.session_context(autocommit=False)
-        yield session
-        default_sql_storage.session_context.shutdown()
+    def sync_sql_session(event_loop, test_sql_storage):
+        block = SqlBlock(test_sql_storage)
+        block.sync_startup()
+        block.sync_session_begin(autocommit=False)
+        yield
+        block.sync_session_finish()
+        block.sync_shutdown()
 
     @pytest.fixture(scope='function')
-    async def async_sql_session(event_loop):
-        session = await default_sql_storage.async_session_context(autocommit=False)
-        yield session
-        await default_sql_storage.async_session_context.shutdown()
+    async def async_sql_session(event_loop, test_sql_storage):
+        block = SqlBlock(test_sql_storage)
+        await block.startup()
+        await block.session_begin(autocommit=False)
+        yield
+        await block.session_finish()
+        await block.shutdown()
 
 
 if USE_REDIS:
     @pytest.fixture(scope='module')
-    def wire_redis_storage():
-        default_redis_storage.wire()
+    def wire_redis_storage(test_redis_storage):
+        test_redis_storage.wire()
         yield
-        default_redis_storage.unwire()
+        test_redis_storage.unwire()
 
     @pytest.fixture(scope='function')
-    async def redis_session(event_loop, wire_redis_storage):
-        session = await default_redis_storage.session_context.init()
-        yield session
-        await default_redis_storage.session_context.shutdown()
+    async def redis_session(event_loop, wire_redis_storage, test_redis_storage, redis_engine):
+        block = RedisBlock(test_redis_storage)
+        await block.startup()
+        await block.session_begin()
+        yield
+        await block.session_finish()
+        await block.shutdown()
 
 
 if USE_RMQ:
     @pytest.fixture(scope='module')
-    def wire_rmq_storage():
-        default_rmq_storage.wire()
+    def wire_rmq_storage(test_rmq_storage):
+        test_rmq_storage.wire()
         yield
-        default_rmq_storage.unwire()
+        test_rmq_storage.unwire()
 
     @pytest.fixture(scope='function')
-    async def rmq_session(event_loop, wire_rmq_storage):
-        session = await default_rmq_storage.session_context.init()
-        yield session
-        await default_rmq_storage.session_context.shutdown()
+    async def rmq_session(event_loop, wire_rmq_storage, test_rmq_storage, rmq_engine):
+        block = RmqBlock(test_rmq_storage)
+        await block.startup()
+        await block.session_begin()
+        yield
+        await block.session_finish()
+        await block.shutdown()
